summaryrefslogtreecommitdiff
path: root/apps/keymaps
diff options
context:
space:
mode:
authorMaurus Cuelenaere <mcuelenaere@gmail.com>2008-08-23 09:46:38 +0000
committerMaurus Cuelenaere <mcuelenaere@gmail.com>2008-08-23 09:46:38 +0000
commit1392dc2144a4b1810ba5c421f54e05dc1a3a74c7 (patch)
tree7f7f7d6dd6ce00e8146896456549441d4e8153d7 /apps/keymaps
parent965d2af61f5035dcf5179b8539785de641a9f015 (diff)
downloadrockbox-1392dc2144a4b1810ba5c421f54e05dc1a3a74c7.zip
rockbox-1392dc2144a4b1810ba5c421f54e05dc1a3a74c7.tar.gz
rockbox-1392dc2144a4b1810ba5c421f54e05dc1a3a74c7.tar.bz2
rockbox-1392dc2144a4b1810ba5c421f54e05dc1a3a74c7.tar.xz
Commit FS#9308: differentiate between TOUCHPAD & TOUCHSCREEN
git-svn-id: svn://svn.rockbox.org/rockbox/trunk@18338 a1c6a512-1295-4272-9138-f99709370657
Diffstat (limited to 'apps/keymaps')
-rw-r--r--apps/keymaps/keymap-touchscreen.c (renamed from apps/keymaps/keymap-touchpad.c)6
1 files changed, 3 insertions, 3 deletions
diff --git a/apps/keymaps/keymap-touchpad.c b/apps/keymaps/keymap-touchscreen.c
index b658fe4..a56eefd 100644
--- a/apps/keymaps/keymap-touchpad.c
+++ b/apps/keymaps/keymap-touchscreen.c
@@ -19,7 +19,7 @@
*
****************************************************************************/
/* Button Code Definitions for touchpad targets */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
@@ -34,7 +34,7 @@ const struct button_mapping* target_get_context_mapping(int context);
get_context_mapping() at the bottom of the file is called by action.c as usual.
if the context is for the remote control its then passed straight to
target_get_context_mapping().
- These tables are only used for the touchpad buttons, so at the end of each
+ These tables are only used for the touchscreen buttons, so at the end of each
CONTEXT_CUSTOM2 is OR'ed with the context and then sent to target_get_context_mapping()
(NOTE: CONTEXT_CUSTOM2 will be stripped before being sent to make it easier.)
In the target keymap, remember to |CONTEXT_CUSTOM2 in the LAST_ITEM_IN_LIST__NEXTLIST() macro
@@ -43,7 +43,7 @@ const struct button_mapping* target_get_context_mapping(int context);
*/
-/* touchpad "buttons"
+/* touchscreen "buttons"
screen is split into a 3x3 grid for buttons...
BUTTON_TOPLEFT BUTTON_TOPMIDDLE BUTTON_TOPRIGHT
BUTTON_MIDLEFT BUTTON_CENTER BUTTON_MIDRIGHT
@@ -19,7 +19,7 @@
*
****************************************************************************/
-/* Button Code Definitions for touchpad targets */
+/* Button Code Definitions for touchscreen targets */
#include <stdio.h>
#include <string.h>